<?php
/**
 *  @package	PaidSystem
 *  @copyright	Copyright (C) 2010-2014 Juloa.com. All rights reserved.
 *  @license    GNU General Public License version 3, or later
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

JTable::addIncludePath(JPATH_ADMINISTRATOR.DS.'components'.DS.'com_paidsystem'.DS.'tables');
jimport('joomla.application.component.controller');

/**
 * Content Component Controller
 *
 * @package		Joomla
 * @subpackage	Content
 * @since 1.5
 */
class PaidsystemControllerFeatureds extends TController
{
	function __construct($config= array()) {
		parent::__construct($config);
	
		// Apply, Save & New
		$this->registerTask('apply', 'save');
		$this->registerTask('save2new', 'save');
	}
	
	function init()
	{
		// Set the default view name from the Request
		$this->_view = $this->getView("admin",'html');

		// Push a model into the view
		$this->_model = $this->getModel( "featured");
		if (!JError::isError( $this->_model )) {
			$this->_view->setModel( $this->_model, true );
		}
		
		$uri = JFactory::getURI();
		$baseurl = JURI::base()."../";

		$this->_view->assign("baseurl",$baseurl);
		$this->_view->assignRef("baseurl",$baseurl);
	}
	
	function display($cachable = false, $urlparams = false)
	{
		$this->canAccess();
		$this->init();
		$this->_view->setLayout("featureds");
		$this->_view->display();
	}
	
	function edit()
	{
		$this->canAccess();
		$this->init();

		$this->_view->setLayout("editfeatured");
		$this->_view->display();
	}
	
	function add()
	{
		$this->canAccess();
		$this->init();

		$this->_view->setLayout("editfeatured");
		$this->_view->display();
	}
	
	function remove()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$featured = JTable::getInstance('featured', 'PaidsystemTable');
		
		$ids = JRequest::getVar( 'tid', array(0));
		if (!is_array($ids)) {
			$table = array();
			$table[0] = $ids;
			$ids = $table;
		}
		foreach($ids as $id){
			$featured->delete($id);
		}
		
		$app->redirect( 'index.php?option=com_paidsystem&c=featureds', JText::_('PAIDSYSTEM_FEATURED_REMOVED'),"message" );
	}
	
	function unpublish()
	{
		$this->_changeState();
	}
	
	function publish()
	{
		$this->_changeState();
	}
	
	function save()
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$featured = JTable::getInstance('featured', 'PaidsystemTable');

		$post = JRequest::get( 'post' );
        
        $post['params_acl'] = implode(',', $post['params_acl']);
        
		// bind it to the table
		if (!$featured -> bind($post)) {
			return JError::raiseWarning( 500, $featured->getError() );
		}
		
		// store it in the db
		if (!$featured -> store()) {
			return JError::raiseWarning( 500, $featured->getError() );
		}	
		
		$field_catsid = JRequest::getVar("field_catsid", array() );
		$field_catsid = ",".implode(',', $field_catsid).",";
		if ($field_catsid != "")
		{
			$featured->savecatsid($featured->id,$field_catsid);
			
		}

		// Redirect the user and adjust session state based on the chosen task.
		$task = JRequest::getCmd('task');
		switch ($task)
		{
			case 'apply':
				$app->redirect( 'index.php?option=com_paidsystem&c=featureds&task=edit&tid[]='.$featured->id, JText::_('PAIDSYSTEM_FEATURED_SAVED'),"message" );
				break;
		
			case 'save2new':
				$app->redirect( 'index.php?option=com_paidsystem&c=featureds&task=add', JText::_('PAIDSYSTEM_FEATURED_SAVED') ,"message");
				break;
		
			default:
				$app->redirect( 'index.php?option=com_paidsystem&c=featureds', JText::_('PAIDSYSTEM_FEATURED_SAVED'),"message" );
			break;
		}
	}
	
	function _changeState()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$cid		= JRequest::getVar( 'tid', array(), '', 'array' );
		$publish	= ( $this->getTask() == 'publish' ? 1 : 0 );

		JArrayHelper::toInteger($cid);

		if (count( $cid ) < 1)
		{
			$action = $publish ? 'publish' : 'unpublish';
			JError::raiseError(500, JText::_( 'Select an item to' .$action, true ) );
		}
		
		$model = $this->getModel( "featured");
		$model->changeState("#__paidsystem_featured","id","published",$publish,$cid);
		
		$cache = JFactory::getCache('com_adsmanager');
		$cache->clean();

		$app->redirect( 'index.php?option=com_paidsystem&c=featureds' );
	}	
	
	function orderdown()
	{
		$this->_changeOrder(1);
	}
	
	function orderup()
	{
		$this->_changeOrder(-1);
	}
	
	function _changeOrder($inc)
	{
		$this->canAccess();
		$app = JFactory::getApplication();
		
		$cid		= JRequest::getVar( 'tid', array(), '', 'array' );
		
		if ($cid[0]) {
			$id = $cid[0];
			$row = JTable::getInstance('featured', 'PaidsystemTable');
			$row->load( $id );
			$row->move( $inc, "1" );
		}

		$app->redirect( 'index.php?option=com_paidsystem&c=featureds' );
	}
	
	function saveorder()
	{
		$this->canAccess();
		$app = JFactory::getApplication();

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );
	
		// Initialize variables
		$cid 	= JRequest::getVar('tid', array(0), 'post', 'array');
		JArrayHelper::toInteger($cid, array(0));
		$total		= count( $cid );
		$order 		= JRequest::getVar( 'order', array(0), 'post', 'array' );
		JArrayHelper::toInteger($order, array(0));
	
		$row = JTable::getInstance('featured', 'PaidsystemTable');

		// update ordering values
		for( $i=0; $i < $total; $i++ ) {
			$row->load( (int) $cid[$i] );
			if ($row->ordering != $order[$i]) {
				$row->ordering = $order[$i];
				if (!$row->store()) {
					JError::raiseError(500, $row->getError() );
				}
			}
		}
		
		// Check if i'm using an AJAX call, in this case there is no need to redirect
		$format = JRequest::getVar('format','');
		$status="";
		if ($format == 'json')
		{
			echo json_encode($status);
		
			return;
		}

		$app->redirect( 'index.php?option=com_paidsystem&c=featureds' );
	}

	private function canAccess() {
		$app = JFactory::getApplication();

		//check if the user can access the categories
		$user = JFactory::getUser();
		if(!$user->authorise('paidsystem.accessfeatured','com_paidsystem')) {
			$app->redirect('index.php', JText::_('JERROR_ALERTNOAUTHOR'), 'error');
		}

		return true;
	}
}
